@@ -18,8 +18,9 @@ class ReturnStatus(Enum):
     OBSTRUCTED = "OBSTRUCTED"
     OUT_OF_REACH = "OUT_OF_REACH"
     NOT_AGENT = "NOT_AGENT"
-    AGENT_CURRENTLY_INTERACTING_WTIH_PERFORMER = \
-        "AGENT_CURRENTLY_INTERACTING_WTIH_PERFORMER"
+    AGENT_IS_BUSY = "AGENT_IS_BUSY"
+    AGENT_CURRENTLY_INTERACTING_WITH_PERFORMER = \
+        "AGENT_CURRENTLY_INTERACTING_WITH_PERFORMER"
     SUCCESSFUL = "SUCCESSFUL"
     SUCCESSFUL_WITH_INVALID_PARAMETERS = "SUCCESSFUL_WITH_INVALID_PARAMETERS"
     UNDEFINED = "UNDEFINED"
