@@ -1,6 +1,6 @@
-import machine_common_sense as mcs
+from runner_script import SingleFileRunnerScript
 
-from .runner_script import SingleFileRunnerScript
+import machine_common_sense as mcs
 
 action_list_from_file = []
 
